// Tiny Whoop mullet canopy for LST-S2 camera
// Material: ABS/PLA

// Parameters

// Render quality / Качество обработки
$fn = 64; // [32:32:128]
// Diameter of mounting holes / Диаметр крепежных отверстий
mountholes = 1.8; // [0.8:0.05:3]
// Camera vertical position / Вертикальное положение камеры
mountheight = 1.2; // [0:0.05:10]
// Camera horizontal position / Горизонтальное положение камеры
mountlenght = 13; // [13:0.5:16]
// Camera angle / Угол наклона камеры
cameraangle = 18; // [5:0.5:35]
// Show LST-S2 camera / Показывать камеру LST-S2
camerashow = true; // [true,false]
// Stand holes / Отверстия для установки на основание
standholes = true; // [true,false]
// Canopy transparency / Прозрачность канопы
canopyalpha = 50; // [0:5:100]
// Canopy color / Цвет канопы
canopycolor = "Fuchsia"; // ["White","Red","Blue","Yellow","Black","Fuchsia"]

//-------------------------------------------------------------------------
// Do not edit following lines
//-------------------------------------------------------------------------

include <camera.scad>;

if (mountheight<0 || mountheight>10) {
    echo ("<b><font color='red'>Camera vertical position must be between 0-10 mm</b>");
    assert(false);
}

if (mountlenght<12.5 || mountlenght>16) {
    echo ("<b><font color='red'>Camera horizontal position must be between 12.5-16 mm</b>");
    assert(false);
}

if (cameraangle<5 || cameraangle>35) {
    echo ("<b><font color='red'>Camera angle must be between 5-35 mm</b>");
    assert(false);
}

module canopy() {
    // SVG-outlines
    sides = "sides.stl";
    bottom = "bottom.svg";
    mount = "mount.svg";
    mount_size=18.385;
    
    difference() {
        union() {
            // Mount sides
            difference() {
                translate([-mount_size,0,-2.3]) scale([1,1,1.25]) import(sides, convexity=10);
                // Lens cut
                rotate([0,-52+cameraangle/2,0]) translate([10,0,20]) cube([20,30,60],center=true);
                translate([-18,0,-10]) cube([60,60,20],center=true);
                // Top cut
                translate([-mountlenght,0,mountheight]) rotate([0,-abs(cameraangle),0]) translate([0,0,34-mountheight-(mountlenght-13)]) cube([100,30,40],center=true);
                // Backward cut
                translate([-40,0,00]) rotate([0,55,0]) translate([-10,0,20]) cube([20,30,60],center=true);
            }

            // Canopy base
            hull() {
                translate([-mountlenght,0,mountheight]) rotate([0,-abs(cameraangle),0])
                // Shell around camera
                union() {
                    //camera();
                    // Right side
                    translate([0,-11,8.5]) rotate([12,12,55]) rotate_extrude(angle=60) translate([20,0,0]) scale([0.22,1,1]) circle(r=4.8);
                    // Left side
                    translate([0,11,8.5]) rotate([-12,12,-55]) rotate_extrude(angle=-60) translate([20,0,0]) scale([0.22,1,1]) circle(r=4.8);
                    // Right fillet
                    translate([-0.5,1,1.2]) rotate([112,0,0]) rotate([5,0,27]) rotate_extrude(angle=115) translate([12.5,0,0]) circle(r=5.2);
                    // Left fillet
                    translate([-0.5,-1,1.2]) rotate([68,0,0]) rotate([-5,0,27]) rotate_extrude(angle=115) translate([12.5,0,0]) circle(r=5.2);
                    // Center fillet
                    translate([-1.2,0,0.5]) rotate([90,-35,0]) rotate_extrude(angle=110) translate([15.5,0,0]) scale([0.4,1,1]) circle(r=6.5);
                    // Ring around lens
                    translate([11.5,0,5.825]) rotate([0,90,0]) rotate_extrude(angle=360) translate([3.51,0,0]) circle(r=3.5);
                }
                // Backward heel
                translate([-mount_size*2,0,0]) difference() {
                    translate([0,0,-1.2]) scale([1.5,0.9,1.2]) sphere(r=5,center=true);
                    translate([0,0,-4]) cube([16,16,8],center=true);
                }
                // Bottom curve
                translate([-18,0,0])  linear_extrude(height=0.001,center=true) import(bottom, convexity=10);
            }
        }
        // Lens hole
        translate([-mountlenght,0,mountheight]) rotate([0,-abs(cameraangle),0]) translate([13.2,0,5.825]) rotate([0,90,0]) cylinder(r=5,h=14);
        // Air hole
        translate([-mountlenght,0,mountheight]) rotate([0,-abs(cameraangle),0]) translate([15,0,-9]) rotate([90,5,180]) rotate_extrude(angle=100) translate([15,0,0]) circle(r=1.5);
        // Mount holes
        translate([-mount_size,mount_size,-1]) cylinder(r=mountholes/2,h=10);
        translate([-mount_size,-mount_size,-1]) cylinder(r=mountholes/2,h=10);
        // Stand holes
        if (standholes) {
            translate([-3,0,-1]) cylinder(r=2.1,h=3);
            translate([-34,0,-1]) cylinder(r=2.1,h=3);
        }
        // Bottom cut
        translate([-18,0,-10]) cube([60,60,20],center=true);
    }
}

// Show camera
if (camerashow) translate([-mountlenght,0,mountheight]) rotate([0,-abs(cameraangle),0]) camera();
// Show canopy
color(canopycolor,canopyalpha/100) canopy();
//projection(cut = false) difference() {
//    canopy();
//    translate([0,0,50.001]) cube([200,200,100],center=true);
//}